==> qtjambi-qml-debuginfo-macos-6.7.0.jar: sources/QtJambiQml/QQmlExtensionPlugin_shell.h <==
#ifndef QQMLEXTENSIONPLUGIN_SHELL_H
#define QQMLEXTENSIONPLUGIN_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQml/qqmlextensionplugin.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QScopedPointer>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qqmlengine.h>
#include <QtJambi/RegistryAPI>


class QQmlExtensionPlugin_shell : public QQmlExtensionPlugin, public QtJambiShellInterface
{
public:
    QQmlExtensionPlugin_shell(QObject* parent0 = nullptr);
    ~QQmlExtensionPlugin_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void initializeEngine(QQmlEngine* engine0, const char* uri1) override;
    void registerTypes(const char* uri0) override;
    void timerEvent(QTimerEvent* event0) override;
    void unregisterTypes() override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQmlExtensionPlugin_access : public QQmlExtensionPlugin
{
    void __qt_initializeEngine_QQmlEngine_ptr_const_char_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID engine0, jstring uri1);
    void __qt_registerTypes_const_char_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring uri0);
    void __qt_unregisterTypes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QQMLEXTENSIONPLUGIN_SHELL_H

==> qtjambi-qml-debuginfo-macos-6.9.1.jar: sources/QtJambiQml/QQmlExtensionPlugin_shell.h <==
#ifndef QQMLEXTENSIONPLUGIN_SHELL_H
#define QQMLEXTENSIONPLUGIN_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQml/qqmlextensionplugin.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QScopedPointer>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qqmlengine.h>
#include <QtJambi/RegistryAPI>


class QQmlExtensionPlugin_shell : public QQmlExtensionPlugin, public QtJambiShellInterface
{
public:
    QQmlExtensionPlugin_shell(QObject* parent0 = nullptr);
    ~QQmlExtensionPlugin_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QQmlExtensionPlugin_mshell;
    friend class QQmlExtensionPlugin_oshell;
};


class QQmlExtensionPlugin_mshell : public QQmlExtensionPlugin_shell
{
public:
    using QQmlExtensionPlugin_shell::QQmlExtensionPlugin_shell;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QQmlExtensionPlugin_oshell : public QQmlExtensionPlugin_mshell
{
public:
    using QQmlExtensionPlugin_mshell::QQmlExtensionPlugin_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void initializeEngine(QQmlEngine* engine0, const char* uri1) override;
    void registerTypes(const char* uri0) override;
    void timerEvent(QTimerEvent* event0) override;
    void unregisterTypes() override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQmlExtensionPlugin_access : public QQmlExtensionPlugin
{
    void __qt_initializeEngine_QQmlEngine_ptr_const_char_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID engine0, jstring uri1);
    void __qt_registerTypes_const_char_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring uri0);
    void __qt_unregisterTypes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QQMLEXTENSIONPLUGIN_SHELL_H
